#
# spec file for package privoxy
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%if 0%{?suse_version} > 1210
%define with_systemd 1
%else
%define with_systemd 0
%endif

%if %{with_systemd}
%if 0%{?suse_version} < 1230
%define _unitdir /lib/systemd/system
%else
%define _unitdir /usr/lib/systemd/system
%endif
%endif

Name:           minidlna
Summary:        DLNA server software
Version:        1.1.4
Release:        1.38
Url:            http://sourceforge.net/projects/minidlna
Source0:        minidlna-%{version}.tar.gz
Source1:        minidlnaconfig
Source2:        minidlna.sysconfig
Source3:        minidlna.logrotate
Source4:        minidlna.service
Source5:        minidlna.init
Patch0:         minidlna-vdr.diff
License:        GPL-2.0
Group:          Productivity/Multimedia/Other
%if %{with_systemd}
PreReq:         %fillup_prereq
%else
PreReq:         %fillup_prereq %insserv_prereq
%endif
Requires:       /usr/bin/sed
Requires:       /usr/bin/egrep
Requires:       /sbin/ifconfig
Requires:       logrotate
BuildRequires:  flac-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libogg-devel
BuildRequires:  libexif-devel
BuildRequires:  sqlite-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libid3tag-devel
BuildRequires:  libffmpeg-devel
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  libtool
%if %{with_systemd}
BuildRequires:  systemd
%{?systemd_requires}
%endif
BuildRoot:	%{_tmppath}/%{name}-%{version}-build

%description
MiniDLNA (aka ReadyDLNA) is server software with the aim
of being fully compliant with DLNA/UPnP-AV clients.

It is developed by a NETGEAR employee for the ReadyNAS product line.
So if you are looking for a NAS, please consider ReadyNAS first!

Credit goes to: Justin Maggard

%prep
%setup -q -n minidlna-%{version}
%patch0

%build
%configure --disable-silent-rules
%__make %{?jobs:-j %jobs}

%install
%makeinstall
install -D -m755 %{S:1} %{buildroot}%{_sbindir}/minidlnaconfig
install -D -m644 %{S:2} %{buildroot}%{_var}/adm/fillup-templates/sysconfig.minidlna
install -D -m644 %{S:3} %{buildroot}%{_sysconfdir}/logrotate.d/minidlna
%if %{with_systemd}
install -D -m644 %{S:4} %{buildroot}%{_unitdir}/minidlna.service
%if 0%{?suse_version} >= 1310
ln -sf /usr/sbin/service %{buildroot}%{_sbindir}/rcminidlna
%else
ln -sf /sbin/service %{buildroot}%{_sbindir}/rcminidlna
%endif
%else
install -D -m755 %{S:5} %{buildroot}%{_sysconfdir}/init.d/minidlnad
ln -s %{_sysconfdir}/init.d/minidlnad %{buildroot}%{_sbindir}/rcminidlnad
%endif
install -D -m644 minidlna.conf.5 %{buildroot}%{_mandir}/man5/minidlna.conf.5
install -D -m644 minidlnad.8 %{buildroot}%{_mandir}/man8/minidlnad.8
install -d -m755 %{buildroot}%{_var}/cache/minidlna
install -d -m755 %{buildroot}%{_var}/lib/minidlna
install -d -m755 %{buildroot}%{_var}/log/minidlna

%find_lang minidlna

%pre
%if %{with_systemd}
%service_add_pre minidlna.service
%endif

%post
%if %{with_systemd}
%fillup_only minidlna
%service_add_post minidlna.service
%else
%fillup_and_insserv minidlnad
%endif

%preun
%if %{with_systemd}
%service_del_preun minidlna.service
%else
%stop_on_removal minidlnad
%endif

%postun
%if %{with_systemd}
%service_del_postun minidlna.service
%else
%restart_on_update minidlnad
%insserv_cleanup
%endif

%files -f minidlna.lang
%defattr(-,root,root)
%{_sbindir}/minidlnaconfig
%{_sbindir}/minidlnad
%if %{with_systemd}
%{_unitdir}/minidlna.service
%{_sbindir}/rcminidlna
%else
%{_sbindir}/rcminidlnad
%config %{_sysconfdir}/init.d/minidlnad
%endif
%config(noreplace) %{_sysconfdir}/logrotate.d/minidlna
%{_var}/adm/fillup-templates/sysconfig.minidlna
%dir %{_var}/cache/minidlna
%dir %{_var}/lib/minidlna
%dir %{_var}/log/minidlna
%{_mandir}/man5/minidlna.conf.5.gz
%{_mandir}/man8/minidlnad.8.gz
%doc AUTHORS LICENCE* NEWS README TODO

%changelog
* Thu Aug 28 2014 joerg.lorenzen@ki.tng.de
- update to 1.1.4
  - Add magic container infrastructure.
  - Add magic containers for 50 recent items for each category.
  - Fix bad null termination in AAC parsing.
  - Fix requests for the last byte of a file, which affected MKV playback on Philips TV's.
  - Support 64-bit time_t values.
  * added %%pre section and symlink to /usr/sbin/service (systemd)
* Sat Jun  7 2014 joerg.lorenzen@ki.tng.de
- update to 1.1.3
  - Enhance log level settings.
  - Fix Samsung browsing when root_container is set.
  - Add Clang compiling support.
  - Fix compiling on systems without iconv.
  - Add merge_media_dirs option, to revert to the old behavior.
  - Add Asus O!Play client support.
  - Fix Broken SSDP multicast membership addition.
  - Fix crash bug with an emtpy filter argument.
  - Accept SMI subtitles in addition to SRT.
  - Add BubbleUPnP detection and enable subtitle support.
  - Allow the user to specify an arbitrary root container.
  - Add libavcodec > 54 / libav 10 compatibility.
  - Get embedded cover art from video files with recent libavformat versions.
  - Disable Samsung DCM10 capability, as it breaks compatibility with new models.
  - Add subtitle support for NetFront™ Living Connect middleware-based clients.
  * added new option merge_media_dirs to file sysconfig and script minidlnaconfig
* Tue Mar 11 2014 joerg.lorenzen@ki.tng.de
- update to 1.1.2
  - Show client status on our basic presentation page.
  - Add a new force_sort_criteria option, to globally override the SortCriteria value sent by the client.
  - Fix a couple resource leaks.
  - Add configuration include file support.
  - Support DLNA/UPnP-AV searches issued by clients using the Grilo framework.
  - Fix some clients playing artwork instead of movie.
  - Fix bookmarks on Samsung Series E clients.
  - Add an extra folder level if there are multiple media locations.
  - Fix some multicast membership issues with changing network settings.
  - Make max number of children (connections) configurable.
  - Fix choppy playback with some file types on Panasonic clients by increasing the max connection limit.
  * added two new options to file sysconfig and script minidlnaconfig
* Fri Jan 10 2014 joerg.lorenzen@ki.tng.de
- fixed minidlnaconfig to allow white space in sysconfig variables
- increased maximum wait time for an configuered network interface
  to 20 seconds, 10 are apparently not enough
* Tue Jan  7 2014 joerg.lorenzen@ki.tng.de
- added check to minidlnaconfig if network interface is configured,
  clients don't see the minidlna server when network interface wasn't
  configuered on minidlna startup
* Sat Jan  4 2014 joerg.lorenzen@ki.tng.de
- added option to sysconfig to enable/disable full rescan of media
  directories on minidlna startup
* Wed Jan  1 2014 joerg.lorenzen@ki.tng.de
- fixed shell script for generation of config file, media directories
  were implemented incorrectly
* Sun Dec 29 2013 joerg.lorenzen@ki.tng.de
- changed pid-file directory to /var/run with systemd
- fixed description for "media_dir" in sysconfig file
* Fri Dec 20 2013 joerg.lorenzen@ki.tng.de
- update to 1.1.1
  - added init script and service to start with sysvinit or systemd
  - added shell script to generate minidlna.conf with sysconfig
  * Add network interface monitoring support on Linux.
  * Don't require a configured network interface to start up.
  * Fix some minor spec compliance issues.
- version 1.1.0
  * Add support for other operating systems.
  * Switch to autoconf from our handcrafted genconfig.sh.
  * Add configuration option for UUID.
  * Add configuration option to specify the user to run as.
  * Add support for limiting a media dir to multiple media types.
  * Force a rescan if we detect a new or missing media_dir entry.
  * Fix crash caused by certain TiVo clients.
  * Fix crash bug on video files with some ffmpeg library versions.
  * Add support for TiVo MPEG-TS files.
  * Add some logging and forking tweaks to work better with systemd.
  * Validate or escape user input to prevent SQL injection.
  * Add forced sorting support for Panasonic devices.
* Thu Dec 13 2012 seife+obs@b1-systems.com
- update to 1.0.25
  * Fix a couple crash bugs on malformed WAV files.
  * Forcibly tweak the model number for Xbox360 clients, or they might ignore us.
  * Enable all network interfaces by default if none were specified.
  * Add flag to force downscaled thumbnails rather than using embedded ones.
  * Add DirecTV client detection, and fix image resolution issue.
  * Add support for the latest ffmpeg/libav library versions.
  * Fix a potential crash on requests for a resize of a non-existent image.
  * Make DeviceID checking more permissive for Sagem Radio.
- add patch to allow VDR recordings
* Thu May 31 2012 Manfred.Tremmel@iiv.de
- update to 1.0.24
  * Fix playlist browsing with no SortOrder specified.
  * Fix inotify detection of caption file removal.
  * Handle an empty DeviceID from Zyxel media player SOAP request.
  * Fix false positives in playlist caching optimization when we have duplicate
    file names in different directories.
  * Trim the camera model name extracted from EXIF tags.
  * Add support for user-configurable log level settings.
  * Add DLNA.ORG_FLAGS support.
- 1.0.23
  * Enable the subtitle menu on some Samsung TV's.
  * Add subtitle support for Panasonic TV's.
  * Add workarounds for LifeTab tablets' bad behavior.
  * Speed up playlist parsing.
  * Make metadata-based virtual containers case insensitive.
  * Add folder art support (very few clients support this though).
  * Improve trimming of quotation marks.
  * Fix SRT caption support with the latest Samsung Series D firmware.
  * Fix subtitles on LG TV's for items whose titles don't have a dot in them.
  * Add support for the av:mediaClass tag, so some Sony devices can filter items
    by media type.
  * Fix inotify detection issues on first-level folders.
  * Work around LifeTab's broken DLNA support.
  * Add image rotation support during resize. (mostly useful for TiVo)
- ffmpeg calls are outdated, compile against ffmpeg_oldabi
* Sun Nov 20 2011 pascal.bleser@opensuse.org
- initial version (1.0.22)
